@@ -3,19 +3,14 @@ from typing import Dict, Optional
 from uuid import uuid4
 
 from django.apps.config import cached_property
+
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from django_extensions.db.models import TimeStampedModel
 
-
 logger = logging.getLogger(__name__)
 BNULL = {"blank": True, "null": True}
 
-class TrackWithScrobbleskManager(models.Manager):
-    def get_queryset(self):
-        return self.super().get_queryset().annotate(scrobble_count=models.Count('scrobble'))
-
-
 
 class Album(TimeStampedModel):
     uuid = models.UUIDField(default=uuid4, editable=False, **BNULL)
@@ -41,11 +36,6 @@ class Artist(TimeStampedModel):
     def __str__(self):
         return self.name
 
-    def scrobble_count(self, filter: Optional[str] = None) -> int:
-        from music.aggregators import artist_scrobble_count
-
-        return artist_scrobble_count(self.id, filter)
-
     @property
     def mb_link(self):
         return f"https://musicbrainz.org/artist/{self.musicbrainz_id}"
@@ -64,7 +54,7 @@ class Track(TimeStampedModel):
     musicbrainz_id = models.CharField(max_length=255, **BNULL)
     run_time = models.CharField(max_length=8, **BNULL)
     run_time_ticks = models.PositiveBigIntegerField(**BNULL)
-    #thumbs = models.IntegerField(default=Opinion.NEUTRAL, choices=Opinion.choices)
+    # thumbs = models.IntegerField(default=Opinion.NEUTRAL, choices=Opinion.choices)
 
     def __str__(self):
         return f"{self.title} by {self.artist}"
